@@ -4,9 +4,11 @@
 #
 # standard library imports
 #
+import binascii
 import io
 import json
 import os
+import re
 import shutil
 import subprocess
 from collections import OrderedDict
@@ -22,6 +24,8 @@ from flask_cli import FlaskCLI
 from flask_rq2 import RQ
 import rq_dashboard
 from healthcheck import HealthCheck, EnvironmentDump
+from sanitize_filename import sanitize
+import pandas as pd
 
 #
 # local imports
@@ -65,6 +69,7 @@ NEWICK_MIMETYPE = "application/newick"
 JSON_MIMETYPE = "application/json"
 FASTA_MIMETYPE = "application/fasta"
 TEXT_MIMETYPE = "text/plain"
+ZIP_MIMETYPE = "application/zip"
 # hmmalign stuff.
 HMM_SWITCHES = {"peptide": "amino", "DNA": "dna"}
 #
@@ -678,7 +683,7 @@ def return_log():
     return Response(content, mimetype=TEXT_MIMETYPE)
 
 
-@app.route("/trees/" + FAMILIES_NAME)
+@app.route("/results/all.json")
 def return_families():
     """Return the list of gene familes.
 
@@ -688,26 +693,79 @@ def return_families():
     return Response(json.dumps(directory_list), mimetype=JSON_MIMETYPE)
 
 
-@app.route("/trees/<family>/alignment", methods=["POST", "GET"])
-def post_or_get_alignment(family):
+@app.route("/calculate", methods=["POST"])
+def post_run():
+    """POST ProteinGraphML run.
+    :return: Success text.
+    """
+    app.logger.debug(f"{request.files}")
+    if 'email' not in request.files:
+        app.logger.error("email not in calculate request.")
+        abort(400)
+    else:
+        email = request.files['email']
+    if 'title' not in request.files:
+        app.logger.error("title not in calculate request.")
+        abort(400)
+    else:
+        title = request.files['title']
+    if 'positives' not in request.files:
+        app.logger.error("positives not in calculate request.")
+        abort(400)
+    else:
+        positives = request.files['positives']
+    # Create run directory
+    run_id = bytes.hex(os.urandom(5))
+    path = Path(app.config["USERDATA"] / run_id)
+    if path.exists() and not path.is_dir():
+        app.logger.warning("Removing existing file in data path name.")
+        path.unlink()
+    if not path.is_dir():
+        app.logger.debug("Creating directory %s.", path)
+        path.mkdir()
+    # put input list in directory
+    try:  # parse gene names
+        positive_list = positives.split()
+        #gene_dict = pd.read_csv()
+        positives_len = len(positive_list)
+        if positive_len < 1:
+            raise ValueError
+    except (ValueError, RuntimeError):
+        app.logger.error(
+            f'Unparseable/empty positives list {positive_list} requested for run {run_id}.')
+        abort(406)
+    positives_frame = pd.DataFrame({"Symbol", positive_list})
+    positives_frame["Label"] = 1
+    positives_frame.to_csv(path/"inputs.csv", index=False)
+    # put email in directory
+    email_regex = re.compile(r"[^@]+@[^@]+\.[^@]+")
+    if email_regex.match(email):
+        with (path/'email.txt').open('w') as email_fh:
+            email_fh.write(f"{email}\n")
+    else:
+        app.logger.error(
+                'Bad email format "{email}" requested for run {run_id}.')
+        abort(406)
+    # Job title, must be sanitized as it will be a directory name
+    if title == "":
+        title = "default"
+    title = sanitize(title)
+    with (path / 'title.txt').open('w') as title_fh:
+        title_fh.write(f"{title}\n")
+    return Response(f"Run {run_id} with title {title} and {positives_len} submitted", mimetype=TEXT_MIMETYPE)
+
+
+@app.route("/results/<runid>/results.zip", methods=["GET"])
+def get_results(runid):
     """POST or GET alignment.
 
     :param family: Family name
     :return: FASTA of alignment on GET
     """
-    test_path = None
-    if request.method == "POST":
-        return create_fasta(family, ALIGNMENT_NAME)
-    elif request.method == "GET":
-        alignment_path = Path(app.config["DATA"]) / family / ALIGNMENT_NAME
-        for ext in SEQUENCE_EXTENSIONS.keys():
-            test_path = alignment_path.with_suffix(SEQUENCE_EXTENSIONS[ext])
-            if test_path.exists():
-                break
-        else:
+    zipfile_path = Path(app.config["USERDATA"]) /runid / "results.zip"
+    if not zipfile_path.exists():
             abort(404)
-        return Response(test_path.open().read(), mimetype=FASTA_MIMETYPE)
-
+    return Response(zipfile_path.open().read(), mimetype=ZIP_MIMETYPE)
 
 @app.route("/trees/<family>.<superfamily>/alignment", methods=["POST", "GET"])
 def post_or_get_alignment_superfamily(family, superfamily):
